/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_BarChart                                             |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for Bar Charts used in the SWA42.  |      
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle     | graph title                                   |
| d_userSubTitle  | graph subtitle                                |
| d_userFootnote  | graph footnote                                |
| d_reportVar     | reporting variable                            |
| d_analysisVar   | analysis variable                             | 
| d_useByVar      | flag to indicate if by var is to be used      |
| d_byVar         | grouping/by variable                          |
|                                                                 |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use analyses which   |
| use Bar charts in their output. These analyses include:         |
| 1. Pareto                                                       |
|                                                                 |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 27NOV08  sindok  initial code                                   |
| 31Dec08  sindok  added code for Multivariate.                   |
| 05Jan09  sinsaa  added code for Pareto and EIThreshold          |
| 27Feb09  gunedu  removed hard-coded usertl libref               |
| 04Mar09  sinsaa  d_analysisVar_t  added to hide the sorted      |
|                  column and changed dsort to asort to address   |
|                  order of the bars.                             |     
| 10Mar09  sinsaa  Removed multivariate analysis specific code as |
|                  sorting is different for Pareto and            |
|                  Multiavriate and hence cannot be included      |
|                  in the same tempalte.                          |
| 16Mar09  sinsaa  Fixed defect S0567234                          |
| 02May09  atbroo  Removing unused d_displayGrid                  |
| 08May09  sindok  Fixed S0579364                                 |
| 08Jun09  sindok  Fixed defect S0584553.                         |
| 23Jun09  sinsaa  Fixed S0581584 M out of N bars(Changed the     |
|                  sorting from ascending to descending           |  
| 01Jul09  sinsaa  Fixed the defect S0590821 Display of           |
|                  reference value                                |
| 06Jul09  sinkah  Made changes for the defect S0569041           |
| 03Aug10  max     new THRESHOLD analysis. S0585374               |
|                  add checks for analysistype=THRESHOLD to use   |
|                  same optional code as EITHRESHOLD.             |
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/

/*
SINDOK: 27th Nov, 2008
1. This code will be executed as a part of install/config process. It will create a statgraph
template which will be stored in an item store, named swagraphs in parmsl.

SINSAA:13Feb2009
1. Changing the library store to usertl.
*/


proc template;


define statgraph swagraphs.barchart/store=usertl.templat;
dynamic d_userTitle
          d_userSubTitle
            d_userFootnote
            d_seperator
            d_vrefValue
            d_vrefLabel

            d_reportVar
            d_reportVarText
            d_analysisVar
            d_analysisVarText
            d_useByVar
            d_byVar
            d_byVarText
            d_distinctByVars
            d_barNumber
         d_analysisVar1

            d_rolename
            d_analysisType

            _BYLINE_
         col1
         col2 
         col3
         col4
         col5
         col6
         col7
         col8
         col9
         col10
         col11
         col12
         col13
         col14
         col15
         col16
         col17
         col18
         col19
         col20
         col21
         col22
         col23
         col24
         col25
            
;

mvar g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle/border=false;
  entrytitle d_userSubTitle" " d_seperator " " _BYLINE_;
  entryfootnote  d_userFootnote;

  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
     entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;

  layout overlay/yaxisopts=( 
       display=all
      label=d_reportVarText
       )

      xaxisopts=( 
      display=all 
      label=d_analysisVarText
       );
  if (upcase(d_analysisType) = "PARETO" OR upcase(d_analysisType) = "EITHRESHOLD" OR upcase(d_analysisType) = "THRESHOLD") 
          barchartparm x=d_reportVar y=eval(dsort(d_analysisVar,retain=all)) /
                                              group=d_byvar name="PARETO" 
                                              orient=HORIZONTAL
                                              legendlabel=d_reportVarText
                                   rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
                                   r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                                    rolename =(TIP1=d_analysisVar1)
                                   TIP =(GROUP X TIP1);
  endif;

         discretelegend "PARETO";

 if (upcase(d_analysisType) = "EITHRESHOLD"  OR upcase(d_analysisType) = "THRESHOLD")  
   referenceline X = d_vrefValue /CURVELABEL=d_vrefLabel;
 endif;

endlayout;

endgraph;
end;
run;
