/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_BarChart_MVA                                         |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for Bar Charts used                |
| in Multivariate Analysis of SWA42.                              |
|                                                                 |
| Example:                                                        |
|                                                                 |
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle     | graph title                                   |
| d_userSubTitle  | graph subtitle                                |
| d_userFootnote  | graph footnote                                |
| d_reportVar     | reporting variable                            |
| d_analysisVar   | analysis variable                             |
| d_useByVar      | flag to indicate if by var is to be used      |
| d_byVar         | grouping/by variable                          |
|                                                                 |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use in Multivariate  |
| analysis.                                                       |
|                                                                 |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 10MAR09  sindok  created using sgTemplate_barChart.sas          |
|                  Seperation required to address the sorting     |
|                  issue specified in S0566546                    |
| 02May09  atbroo  Removing unused d_displayGrid                  |
| 08Jun09  sindok  Fixed defect S0584553.                         |
| 18Aug09  atbroo  Removed sorting (sort happens in output)       |
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


proc template;


define statgraph swagraphs.barchart_MVA/store=usertl.templat;
dynamic d_userTitle
          d_userSubTitle
            d_userFootnote
            d_vrefValue
            d_vrefLabel

            d_reportVar
            d_reportVarText
            d_analysisVar
            d_analysisVarText
            d_useByVar
            d_byVar
            d_byVarText
            d_distinctByVars
            d_barNumber
         d_analysisVar_t

            d_rolename
            d_analysisType

         col1
         col2 
         col3
         col4
         col5
         col6
         col7
         col8
         col9
         col10
         col11
         col12
         col13
         col14
         col15
         col16
         col17
         col18
         col19
         col20
         col21
         col22
         col23
         col24
         col25
            
;

mvar g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;

  layout overlay/yaxisopts=( 
       display=all
       label=d_analysisVarText
       )

      xaxisopts=( 
       display=all 
       label=d_reportVarText
       );
      barchartparm x=d_reportVar y=d_analysisVar / name="MULTIVARIATE" 
                   orient=Vertical legendlabel=d_reportVarText
                   rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                             r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                             r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                             r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                   TIP =(x y);


  discretelegend "MULTIVARIATE";
  endlayout;

endgraph;
end;
run;
