/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_ControlChart                                         |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for Control Charts used in the     |  
| SWA42.                                                          |      
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle     | graph title                                   |
| d_userSubTitle  | graph subtitle                                |     
| d_userFootnote  | graph footnote                                |
| d_reportVar     | reporting variable                            |
| d_analysisVar   | analysis variable                             |
| d_useByVar      | flag to indicate if by var is to be used      |
| d_byVar         | grouping/by variable                          | 
|                                                                 |  
|                                                                 |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use analyses which   |
| use Control Charts in Trend by control analysis output.         |
|                                                                 |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 16JAN09  sinsaa  initial code                                   |
| 27JAN09  sinkah  added option of rows and column in grided layout
|                  so that the control plots will appear one,     |
|                   above the other .                             |
| 18Feb09  gunedu  Changed the template itemstore to usertl       |                                                                |
| 02May09  atbroo  Replacing dynamic var d_displayGrid with mvar  |
|                  g_displayGrid                                  |
|                  Remvoing unused legend                         |    
| 08Jun09  sindok  Fixed defect S0584553.                         |
| 10Jul09  atbroo  Fixed defect S0585847.                         |
| 31Jul09  sindok  Fixed defect S0581297.                         |
| 31Jul09  atbroo  Added dataLabel.                               |
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    | 
| 19Feb14  sindok  Fixed defect S1018075.                         |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright 2014 by SAS Institute Inc., Cary, NC 27513 USA        |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


proc template;
define statgraph swagraphs.ControlChart/store=usertl.templat;
dynamic d_userTitle
        d_userSubTitle
        d_userFootnote
		d_userFootnoteControlChart

      d_xVar
      d_xVarText
      d_yVar1
      d_yVarText1
      d_yVar2
      d_yVarText2

      d_vrefValue11
      d_vrefValue12
      d_vrefValue13

      d_vrefLabel11
      d_vrefLabel12
      d_vrefLabel13

      
      d_vrefValue21
      d_vrefValue22
      d_vrefValue23

      d_vrefLabel21
      d_vrefLabel22
      d_vrefLabel23

;

mvar g_displayGrid g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  if (mean(type) eq 1)
     entrytitle d_userTitle;
     entrytitle d_userSubTitle;
	 entryfootnote halign=left d_userFootnoteControlChart;
  else
     entryfootnote halign=left d_userFootnote;
	   if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;
  endif;


  
  if (mean(type) eq 1)
    layout overlay/     
       yaxisopts=( 
       griddisplay=g_displaygrid
       display=all
       label=d_yVarText1
       )

       xaxisopts=( 
       griddisplay=g_displaygrid 
       display=all 
       label=d_xVarText
       )
    ;
      seriesplot  x=d_xVar y=d_yVar1/name="CONTROL" lineattrs=GraphData1 break=true datalabel=_tests_;
      scatterplot  x=d_xVar y=inpt/name="IN" markerattrs=GraphData1;
      scatterplot  x=d_xVar y=expt/group=_tests_ name="OUT" markerattrs=GraphData11;

      referenceline Y = d_vrefValue11 /CURVELABEL = d_vrefLabel11;
      referenceline Y = d_vrefValue12 /CURVELABEL = d_vrefLabel12;
      referenceline Y = d_vrefValue13 /CURVELABEL = d_vrefLabel13;

    endlayout;
  else
    layout overlay/     
       yaxisopts=( 
       griddisplay=g_displaygrid
       display=all
       label=d_yVarText2
       )

       xaxisopts=( 
       griddisplay=g_displaygrid 
       display=all 
       label=d_xVarText
       )
    ;
      seriesplot  x=d_xVar y=d_yVar2/name="CONTROL" display=(markers)
                  lineattrs=GraphData1 markerattrs=GraphData1 break=true;

      referenceline Y = d_vrefValue21 /CURVELABEL = d_vrefLabel21;
      referenceline Y = d_vrefValue22 /CURVELABEL = d_vrefLabel22;
      referenceline Y = d_vrefValue23 /CURVELABEL = d_vrefLabel23;

    endlayout;
  endif;

endgraph;
end;
run;
