/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_ProbPlot                                             |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for Reliability's Probability      |
| Plot used in the SWA42.                                         |      
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle     | graph title                                   |     
| d_userSubTitle  | graph subtitle                                |     
| d_userFootnote  | graph footnote                                |
| d_reportVar     | reporting variable                            |
| d_analysisVar   | analysis variable                             |
| d_useByVar      | flag to indicate if by var is to be used      |
| d_byVar         | grouping/by variable                          |
|                                                                 |
|                                                                 |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for the probability      |
| plot.                                                           |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 29JAN09  atbroo  initial code                                   |
| 02May09  atbroo  Replacing dynamic var d_displayGrid with mvar  |
|                  g_displayGrid                                  |
| 08Jun09  sindok  Fixed defect S0584553.                         |
| 09Jul09  atbroo  Fixed defect S0567188.                         |
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


proc template;
define statgraph swagraphs.ProbPlot/store=usertl.templat;
dynamic d_userTitle
      d_userSubTitle
      d_userFootnote

      d_tickvaluelist
      d_tickdisplaylist
      d_min
      d_max
      d_xlabels
      d_xvalues

      d_xVar
      d_xVarText
      d_yVar
      d_yVarText
      d_cdfVar
      d_byVar
      d_byVarText

      d_lineAttrs
      d_markerAttrs

      d_rolename

      d_seriesTipVar1
      d_seriesTipLabel1
      d_seriesTipVar2
      d_seriesTipLabel2
      d_seriesTipVar3
      d_seriesTipLabel3
      d_scatterTipVar1
      d_scatterTipLabel1
      d_scatterTipVar2
      d_scatterTipLabel2
      d_scatterTipVar3
      d_scatterTipLabel3

      col1
      col2 
      col3
      col4
      col5
      col6
      col7
      col8
      col9
      col10
      col11
      col12
      col13
      col14
      col15
      col16
      col17
      col18
      col19
      col20
      col21
      col22
      col23
      col24
      col25
;

mvar g_displayGrid g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;

  layout overlay/     
       yaxisopts=( 
         griddisplay=g_displaygrid
         display=all
         label=d_yVarText
         linearopts=(tickvaluelist=d_tickvaluelist tickdisplaylist=d_tickdisplaylist
                     viewmin=d_min viewmax=d_max)
       )

       xaxisopts=( 
         griddisplay=g_displaygrid 
         display=all 
         label=d_xVarText
         linearopts=(tickvaluelist=d_xvalues tickdisplaylist=d_xlabels)
       )
;

            if (exists(d_seriesTipVar1) | exists(d_seriesTipVar2) | exists(d_seriesTipVar3) ) 
               seriesplot  x=d_xVar y=d_cdfVar/ group=d_byVar name="CDF" lineAttrs=d_lineAttrs markerattrs=(size=0 symbol=asterisk)
                        rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
                         r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                         rolename = (seriesRole1=d_seriesTipVar1 seriesRole2=d_seriesTipVar2 seriesRole3=d_seriesTipVar3)
                         tip = (seriesRole1 seriesRole2 seriesRole3)
                         tiplabel = (seriesRole1=d_seriesTipLabel1 seriesRole2=d_seriesTipLabel2 seriesRole3=d_seriesTipLabel3);
            else
               seriesplot  x=d_xVar y=d_cdfVar/ group=d_byVar name="CDF" lineAttrs=d_lineAttrs
                        rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
                        r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);
            endif;

            if (exists(d_scatterTipVar1) | exists(d_scatterTipVar2) | exists(d_scatterTipVar3) ) 
               scatterplot x=d_xVar y=d_yVar/ group=d_byVar name="ProbPlot" markerAttrs=d_markerAttrs
                        rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
                         r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                         rolename = (scatterRole1=d_scatterTipVar1 scatterRole2=d_scatterTipVar2 scatterRole3=d_scatterTipVar3 scatterRole4=d_byVar)
                         tip = (scatterRole1 scatterRole2 scatterRole3 scatterRole4)
                         tiplabel = (scatterRole1=d_scatterTipLabel1 scatterRole2=d_scatterTipLabel2 scatterRole3=d_scatterTipLabel3 );
           else
               scatterplot x=d_xVar y=d_yVar/ group=d_byVar name="ProbPlot" markerAttrs=d_markerAttrs
                        rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
                         r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);
          endif;

            if ( exists(d_byVar) )
               discretelegend "ProbPlot" /Title=d_byVarText;
            endif;

   endlayout;
endgraph;
end;

run;
