/*
---------------------------------------------------------------------------
  NAME:                                                           
  util_allocWARRUSER.sas                                                      
                                                                   
  TYPE:                                                            
  uncompiled macro   
                                                                   
  DESCRIPTION:                                                     
  This program is designed to run from Enterprise Guide/Add-In for Microsoft Office  
  via the SWA custom add-in.  It is executed via a %INCLUDE from the ?.dll                                                                                                                                                                                                  
  
  PROGRAM MODIFICATION EXPECTATIONS: 
  values: PROHIBITED.
                                                                   
  SAS VERSION:                                                     
  V9.2                                               
                                                                   
  INPUT:                                                           
  Macro variables values are defined in this file by the associated template at installation time.                      

      +-----------------------------------------------------------------
      | Input Item Name: g_sasroot
      |   Description: Installation directory of SAS V9.1.3         
      |   Type: macro var
      |   Mode: read only
      |   
     +-----------------------------------------------------------------
      | Input Item Name: g_applRoot
      |   Description: Location of PARMSL_S.LOGIN data set ONLY IF the
      |       SAS/SHARE server defined by &g_shrSrvr is not active 
      |   Type: macro var
      |   Mode: read only
      |   
      +-----------------------------------------------------------------
      | Input Item Name: g_slash
      |   Description: forward or backward slash, as appropriate for OS         
      |   Type: macro var
      |   Mode: read only
      |   
  
  
  OUTPUT:                                                          
          

      +-----------------------------------------------------------------
      | Output Item Name: WARRUSER
      |   Description: Libref assigned to the end-user's SWA FilteredData directory
      |       for READONLY access to the data sets in that library in EG and AMO 
      |   Type: SAS libref
      |   Mode: readonly

                                                                   
  CALLS:                                                           
  Compiled macros from the SWASRCL library: 
   %util_assignUserLibname 
                                                                   
  CALLED BY (optional):                                                       
    .dll of EG/AMO Add-In, and the autoexec for the SASWarrantyAnalysis Workspace Server.                  
                                                                   
  PRECONDITIONS (optional):                                                   
  Access to the SWA PARMSL.USERATTRIBUTES data set and compiled macros is available.                         
                                                                   
  POSTCONDITIONS (optional):                                                  
  WARRUSER library assigned in read-only mode, pointing to a given user's 
  SWA filteredData directory. 
                                                                   
                                                                   
  HISTORY:                                                         
  userid   ddmmmyyyy   subsequent changes
  sasamd   11Feb2008   Brought forwared from SWA V3.1
                       Removed allocation of PARMSL_S.  PARMSL should be
                       preassigned from SMC.
  sinprn   12Feb2008   Changed username to userid as per the change in 4.1.  
  sasamd   16Feb2008   Added symdels to fix conflict with thick client.  
  sasamd   11Apr2008   Added additional symdels to fix S0498211.  
  sinnys   14Aug2009   Changed p_userid to p_username, removed the code to free 
                       reference library and removed symdel g_personomrid
  sascis   06Dec2011   S0796738: Replaced call to util_assignUserLibname with code
                       that will only assign the libname if the directory exists
------------------------------------------------------------------------------
      Copyright (C) 2012 SAS Institute, Inc. All rights reserved.

Notice: 
The above copyright notice and this notice must appear in any whole or partial 
copy of this code and any related documentation. Permission to use, copy and 
modify the source code contained in this file is hereby granted, but is 
limited to customers of SAS with a valid license for the SAS software product 
with which this file was provided. Except as expressly set forth herein, the 
terms of such license apply.
------------------------------------------------------------------------------
*/




/**************************************************************************/ 
/* Global macro variable values below to be set by template at install    */ 
/**************************************************************************/ 
[WARRUSER]


%macro util_allocWARRUSER;


   /* ****************************************************** 
   * Access the SWASRCL library to use compiled macros
   * ****************************************************** */ 

   [optionsPart]

   /* ****************************************************************************** 
   * determine server we are currently running on - needed in util_assignUserLibname 
   * ******************************************************************************* */ 

   [getAppServerName]

   options comamid=tcp autosignon=yes; 
   %global l_personname l_obs l_ERRORMSG;

   %get_metadata_name;

   %if &l_obs > 1 %then %do;
      %let l_ERRORMSG = ERROR: Multiple OMR Names found for the LOGINID "&sysuserid" ;
      %goto MACERROR;
   %end;
   
   /* *****************************************************
   * not using this call because it will create the directory if it does not exist;
   %util_assignUserLibname(p_username=&l_personname,
      p_libname=WARRUSER, p_subDirPath=filteredData,
      p_options=%str(access=readonly));
   ***************************************************** */

   %global g_serverPath g_guarc;        /* cis: S0796738 */
   %local l_dirpath nummems;
   %let nummems = 0;
   %util_getuserattributes(p_personomrname=&l_personname,
                           servername_mv=g_servername,
                           serverpath_mv=g_serverPath
                          );
   %if &g_guarc EQ 0 %then  /* user's data directory exists in the PARMSL.USERATTRIBUTES table */
   %do;
      %let l_dirpath = &g_serverPath.&g_slash.filteredData;
      data _null_;
         rc = filename("tempdir", "&l_dirpath");
         dirid = dopen("tempdir");
         if dirid GT 0 then
            members = dnum(dirid);
         dirid = dclose(dirid);
         call symput("nummems",members);
      run;

      %if &nummems GT 0 %then  /* USERFDL physical directory exists and contains data */
         libname WARRUSER "&l_dirpath" access=readonly;
   %end;

   /* ****************************************************** 
   * Free the reference libraries
   * ****************************************************** */ 
   /* release sasmstore assignment */
   /***sinnys 14Aug2009 : removed the below portion as there is no need to unlock the sasmacr catalog... 
       Also, it resulted in an error which resulted in OBS=0 option ****/

   /*   options sasmstore=sasuser;*/
   /*   %put NOTE: ERROR or WARNING messages may occur on dummy macro compilation, and may be ignored.;*/
   /*   %macro dummy/store;*/
   /*      %put;*/
   /*   %mend;*/
   /*   libname swasrcl clear;*/

   /*
      added symdels to remove global macro variables that conflict 
      with SWA 4.1 thick client
   */

   /* %symdel g_personomrid;*/
   %symdel g_directoryname;
   %symdel g_servername;
   %symdel g_serverpath;
   %symdel g_currencycode;
   %symdel g_msg;
   %symdel g_rc;
   %symdel g_aulRC;
   %symdel g_guaRC;
    
   %macERROR:

   %put &l_Errormsg;

%mend util_allocWARRUSER;

%macro get_metadata_name;
   filename request temp;
   filename response temp lrecl=1024;
   filename map temp;

   %put "sysuserid = " &sysuserid;
    
   data _null_;
	file request;
	put "<GetMetadataObjects>";
   	put 	"<Reposid>$METAREPOSITORY</Reposid> ";
   	put 	"<Type>Person</Type>";
   	put 	"<Objects/>";
   	put 	"<NS>SAS</NS>";
   	put 	"<Flags>388</Flags>";
   	put 	"<Options>";
	put 	"<XMLSelect Search=""Person[Logins/Login[@UserID contains '" "&sysuserid" "']]""/>";
	put 	"<Templates>";
	put 	'<Person Name="" DisplayName=""/>';
	put 	"</Templates>";
	put 	"</Options>";
	put 	"</GetMetadataObjects>";
   run;
	
   proc metadata
	in=request
	out=response;
   run;

   /*
    *   Create Map for xml parsing
    */
   data _null_;
      file map;
      put '<?xml version="1.0" encoding="windows-1252"?>';
      put '<SXLEMAP name="SXLEMAP_Person" version="1.2">';

      put '<TABLE name="DisplayName">';
      put '<TABLE-PATH syntax="XPath">/GetMetadataObjects/Objects/Person/@Id</TABLE-PATH>';

      put '<COLUMN name="Name" retain="YES">';
      put '<PATH syntax="XPath">/GetMetadataObjects/Objects/Person/@Name</PATH>';
      put '<TYPE>character</TYPE>';
      put '<DATATYPE>string</DATATYPE>';
      put '<LENGTH>15</LENGTH>';
      put '</COLUMN>';

      put '<COLUMN name="DisplayName" retain="YES">';
      put '<PATH syntax="XPath">/GetMetadataObjects/Objects/Person/@DisplayName</PATH>';
      put '<TYPE>character</TYPE>';
      put '<DATATYPE>string</DATATYPE>';
      put '<LENGTH>32</LENGTH>';
      put '</COLUMN>';
      put '</TABLE>';
	  put '</SXLEMAP>';
   run;

   libname response xml xmlmap=map;

   /*
    * retrieve OMR NAME into macro variable
    */
   proc sql;
	select Name into :l_personname from response.DisplayName;
   quit;

   %put PersonName is &l_personname;


   proc sql;
	select count(*) into :l_obs from response.displayname;
   quit;

   %put "OBS=" &l_obs;

%mend;
%util_allocWARRUSER;




 
